# -*- coding: utf-8 -*-

from __future__ import print_function
from PyQt5 import QtCore, QtWidgets, QtGui, QtPrintSupport
from PyQt5.QtCore import Qt

import pyqtgraph as pg
import pyqtgraph.exporters

from curves_styles import CurvesStylesCombo

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtWidgets.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtCore.QCoreApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtCore.QCoreApplication.translate(context, text, disambig)


class PGraphWidget(QtWidgets.QWidget):
    def __init__(self, parent):
        QtWidgets.QWidget.__init__(self, parent)
        self.resize(650, 500)
        self.verticalLayout = QtWidgets.QVBoxLayout(self)
        self.toolbar = QtWidgets.QToolBar(self)
        self.toolbar.setIconSize(QtCore.QSize(24,24))
        self.verticalLayout.addWidget(self.toolbar)
        self.comboBox_mode_tracer = QtWidgets.QComboBox()
        self.comboBox_mode_tracer.addItem(_fromUtf8(""))
        self.toolbar.addWidget(self.comboBox_mode_tracer)
        self.comboBox_curves_styles = CurvesStylesCombo(self)
        self.toolbar.addSeparator()
        self.toolbar.addWidget(self.comboBox_curves_styles)
        self.toolbar.addSeparator()
        self.action_export = QtWidgets.QAction(self)
        icon = QtGui.QIcon()
        icon.addFile("icons/save.png")
        self.action_export.setIcon(icon)
        self.toolbar.addAction(self.action_export)
        self.statusBar = QtWidgets.QStatusBar()
        self.statusBar.showMessage("test")
        
        self.comboBox_curves_styles.currentIndexChanged[int].connect(self.setCurveStyle)
        self.action_export.triggered.connect(self.export)        

               
        pg.setConfigOption('background', 'w')
        pg.setConfigOption('foreground', 'k')       
        self.plotWidget = pg.GraphicsWindow()#enableMenu=False)
        self.plotWidget.setCursor(Qt.CrossCursor)
        
        #from PyQt4.QtCore import Qt
        #from PyQt4.QtGui import QApplication, QCursor
        #...
        #QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
        ## do lengthy process
        #QApplication.restoreOverrideCursor()
        
        
        
        
        
        self.verticalLayout.addWidget(self.plotWidget)
        self.verticalLayout.addWidget(self.statusBar)
        
        
        self.points = [[0,1,2,3,4], [1, 3, 5, 7,9]]
        self.labels = xlabel,ylabel,titre ="Abscisses", "Ordonnées", "Pymecavideo"
        self.PointsItem = pg.ScatterPlotItem(self.points[0], self.points[1], pen = 'k', symbol = '+', antialias=True)
        self.CurveItem = pg.PlotCurveItem(self.points[0], self.points[1], pen = 'k', antialias=True)


        self.p1 = self.plotWidget.addPlot(labels={'left' : ylabel, 'bottom' : xlabel}, title=titre, enableMenu = False)

        
        
        
        self.retranslateUi()
        QtCore.QMetaObject.connectSlotsByName(self)
        
        self.setCurveStyle(0)

        
    
    def setCurveStyle(self, item):
        self.curve_style = item
        self.plot(item)
            
    def plot(self, curve_style=0):
        self.p1.clear()
        if curve_style in [0,1,3] :
            self.p1.addItem(self.PointsItem)
        if curve_style in [1,2] :
            self.p1.addItem(self.CurveItem) 
           
        ## RETICULE
        #vLine = pg.InfiniteLine(angle=90, movable=False, pen='b')
        #hLine = pg.InfiniteLine(angle=0, movable=False, pen='b')
        #self.p1.addItem(vLine, ignoreBounds=True)
        #self.p1.addItem(hLine, ignoreBounds=True)
        self.p1vb = self.p1.vb
        
        def mouseMoved(mousePoint):
            #
            curvePoint = self.p1vb.mapSceneToView(mousePoint)
            if self.p1.sceneBoundingRect().contains(mousePoint):
                self.statusBar.showMessage("x = {0:.3f} , y = {1:.3f}".format(curvePoint.x(), curvePoint.y()))
                ## RETICULE
                #vLine.setPos(curvePoint.x())
                #hLine.setPos(curvePoint.y())
            else :
                self.statusBar.clearMessage()
                    
        self.p1.scene().sigMouseMoved.connect(mouseMoved)

        
    def export(self):
        filename, suffix = QtGui.QFileDialog.getSaveFileName(self, "Exporter le graphe", QtCore.QDir.home().absolutePath(), "Image PNG(*.png)")
        
        if filename:
            #print(filename)
            #print(suffix)
            """
            if not ".png" in filename and ".png" in suffix:
                #print('png')
                filename = filename+".png"
            if not ".pdf" in filename and ".pdf" in suffix:
                #print('pdf')
                filename = filename+".pdf"
            
            
            p = QtPrintSupport.QPrinter(QtPrintSupport.QPrinter.ScreenResolution)
            p.setPaperSize(QtPrintSupport.QPrinter.A4)
            p.setOutputFormat(QtPrintSupport.QPrinter.PdfFormat)
            p.setOrientation(QtPrintSupport.QPrinter.Landscape)
            p.setOutputFileName(filename)
            
            pw = self.plotWidget
            original_size = self.plotWidget.width(),self.plotWidget.height()
            pw.resize(0.95*p.paperRect().width(), 0.95*p.paperRect().height())
            #xscale = p.paperRect().width() / pw.plotItem.width()
            #yscale = p.paperRect().height() / pw.plotItem.height()

            #print(p.paperRect())
            #print(xscale,yscale)
            painter = QtGui.QPainter(p)
            #painter.scale(xscale, yscale)
            pw.render(painter)
            painter.end()
            pw.resize(original_size[0], original_size[1])
            """
            if not ".png" in filename :
                filename = filename+".png"
                
            
            image = QtGui.QImage(self.plotWidget.size(), QtGui.QImage.Format_ARGB32)
            painter = QtGui.QPainter(image)
            self.plotWidget.render(painter)
            painter.end()            
            image.save(filename)
            
            
            ### Marche pas : axes, lignes OK mais pas les points !
            #exporter = pg.exporters.ImageExporter(self.plotWidget.plotItem())
            #exporter.export(filename)
            ###       
        
        
    def retranslateUi(self):
        self.setWindowTitle(_translate("Graphe", "Graphique", None))
        self.comboBox_mode_tracer.setItemText(0, _translate("Choisir...", "Choisir ...", None))

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    w = PGraphWidget(None)
    w.show()
    sys.exit(app.exec_())

